package be.iminds.ilabt.jfed.espec.model;

import be.iminds.ilabt.jfed.espec.parser.ESpecDefaults;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.Collections;
import java.util.List;

/**
 * AnsiblePlaybookSpec
 */
public class AnsiblePlaybookSpec implements UploadLikeWithLogSpec {
    @Nonnull
    private final FileSource source;
    @Nullable
    private final String path;
    @Nonnull private final String permissions;
    private final int debug;
    @Nullable private final String log;

    public AnsiblePlaybookSpec(@Nonnull FileSource source,
                               @Nullable String path,
                               @Nullable String permissions,
                               @Nullable Integer debug,
                               @Nullable String log) {
        this.source = source;
        this.path = path;
        this.permissions = permissions == null ? "u=rwx" : permissions;
        this.debug = debug == null ? ESpecDefaults.ANSIBLE_DEBUG : debug;
        this.log = log;
    }

    @Nonnull
    public FileSource getSource() {
        return source;
    }

    @Nullable
    public String getPath() {
        return path;
    }

    @Nonnull
    public String getPermissions() {
        return permissions;
    }

    @Nullable
    @Override
    public String getLog() {
        return log;
    }

    @Nullable
    @Override
    public List<String> getNodes() {
        //special: always only on ansible node
        //value is ignored, but we put something anyway because null would mean ALL nodes and that's also not correct
        return Collections.singletonList("$ANSIBLE_NODE$");
    }

    public boolean isDebug() {
        return debug > 0;
    }

    /**
     * @return number of v's to add to ansible arguments
     */
    public int getDebug() {
        return debug;
    }
}
